==> ify-loader-1.0.0.tgz: package/README.md <==
# ify-loader

[![experimental](http://badges.github.io/stability-badges/dist/experimental.svg)](http://github.com/badges/stability-badges)

[Webpack](https://github.com/webpack/webpack) loader to handle [browserify transforms]() as intended.

## Usage

Install the loader using [npm](https://npmjs.com/):

``` glsl
npm install --save ify-loader
```

You can then update your `webpack.config.js` in a similar fashion to the following to add browserify transform support to your project:

``` javascript
module.exports = {
  module: {
    loaders: [
      // This applies the loader to all of your dependencies,
      // and not any of the source files in your project:
      {
        test: /node_modules/,
        loader: 'ify'
      }
    ]
  }
}
```

## Why?

When given the choice, I lean more in favour of [browserify](http://browserify.org) for its simplicity and compatability with node.js — however from time to time I need to work on projects that use webpack. The thing I run into issues with most often when switching between the two is the difference in how webpack handles source transforms compared to browserify.

Webpack provides you with a "global" configuration where you specify how your project and its dependencies are transformed in a single place. Browserify, however, scopes transforms to the current package to avoid conflicts between different dependencies' sources using the  [`browserify.transform` property](https://github.com/substack/node-browserify#browserifytransform) in `package.json`.

There are pros and cons to both approaches — Webpack gives you more control, at the expense of having to configure each transform used in your dependency tree. Unlike [transform-loader](https://github.com/webpack/transform-loader), *ify-loader* will determine which transforms to apply to your dependencies for you, making the process a lot more bearable in complex projects!

## See Also

* [browserify](https://github.com/substack/node-browserify)
* [webpack](https://github.com/webpack/webpack)
* [transform-loader](https://github.com/webpack/transform-loader)

## License

MIT, see [LICENSE.md](http://github.com/hughsk/ify-loader/blob/master/LICENSE.md) for details.

==> ify-loader-1.0.1.tgz: package/README.md <==
# ify-loader

[![experimental](http://badges.github.io/stability-badges/dist/experimental.svg)](http://github.com/badges/stability-badges)

[Webpack](https://github.com/webpack/webpack) loader to handle [browserify transforms]() as intended.

## Usage

Install the loader using [npm](https://npmjs.com/):

``` glsl
npm install --save ify-loader
```

You can then update your `webpack.config.js` in a similar fashion to the following to add browserify transform support to your project:

``` javascript
module.exports = {
  module: {
    loaders: [
      // This applies the loader to all of your dependencies,
      // and not any of the source files in your project:
      {
        test: /node_modules/,
        loader: 'ify'
      }
    ]
  }
}
```

## Why?

When given the choice, I lean more in favour of [browserify](http://browserify.org) for its simplicity and compatability with node.js — however from time to time I need to work on projects that use webpack. The thing I run into issues with most often when switching between the two is the difference in how webpack handles source transforms compared to browserify.

Webpack provides you with a "global" configuration where you specify how your project and its dependencies are transformed in a single place. Browserify, however, scopes transforms to the current package to avoid conflicts between different dependencies' sources using the  [`browserify.transform` property](https://github.com/substack/node-browserify#browserifytransform) in `package.json`.

There are pros and cons to both approaches — Webpack gives you more control, at the expense of having to configure each transform used in your dependency tree. Unlike [transform-loader](https://github.com/webpack/transform-loader), *ify-loader* will automatically determine which browserify transforms to apply to your dependencies for you the same way that browserify itself does, making the process a lot more bearable in complex projects!

## See Also

* [browserify](https://github.com/substack/node-browserify)
* [webpack](https://github.com/webpack/webpack)
* [transform-loader](https://github.com/webpack/transform-loader)

## License

MIT, see [LICENSE.md](http://github.com/hughsk/ify-loader/blob/master/LICENSE.md) for details.
